"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchApksBundle = exports.patchXapkBundle = void 0;
const cross_zip_1 = require("@tybys/cross-zip");
const fs = require("./utils/fs");
const path = require("path");
const globby = require("globby");
const Listr = require("listr");
const patch_apk_1 = require("./patch-apk");
const observe_async_1 = require("./utils/observe-async");
function patchXapkBundle(options) {
    return patchAppBundle(options, { isXapk: true });
}
exports.patchXapkBundle = patchXapkBundle;
function patchApksBundle(options) {
    return patchAppBundle(options, { isXapk: false });
}
exports.patchApksBundle = patchApksBundle;
function patchAppBundle(options, { isXapk }) {
    const { inputPath, outputPath, tmpDir, uberApkSigner } = options;
    const bundleDir = path.join(tmpDir, 'bundle');
    let baseApkPath = path.join(bundleDir, 'base.apk');
    return new Listr([
        {
            title: 'Extracting APKs',
            task: () => cross_zip_1.unzip(inputPath, bundleDir),
        },
        ...(isXapk
            ? [
                {
                    title: 'Finding base APK path',
                    task: async () => {
                        const manifestPath = path.join(bundleDir, 'manifest.json');
                        const manifestContent = await fs.readFile(manifestPath, 'utf-8');
                        const manifest = JSON.parse(manifestContent);
                        baseApkPath = path.join(bundleDir, getXapkBaseName(manifest));
                    },
                },
            ]
            : []),
        {
            title: 'Patching base APK',
            task: () => patch_apk_1.default({
                ...options,
                inputPath: baseApkPath,
                outputPath: baseApkPath,
                tmpDir: path.join(tmpDir, 'base-apk'),
            }),
        },
        {
            title: 'Signing APKs',
            task: () => observe_async_1.default(async (log) => {
                const apkFiles = await globby(path.join(bundleDir, '**/*.apk'));
                await uberApkSigner
                    .sign(apkFiles, { zipalign: false })
                    .forEach(line => log(line));
            }),
        },
        {
            title: 'Compressing APKs',
            task: () => cross_zip_1.zip(bundleDir, outputPath),
        },
    ]);
}
function getXapkBaseName(manifest) {
    if (manifest.split_apks) {
        return manifest.split_apks.filter((apk) => apk.id === 'base')[0].file;
    }
    return `${manifest.package_name}.apk`;
}
