"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const operators_1 = require("rxjs/operators");
const chalk = require("chalk");
const execute_jar_1 = require("../utils/execute-jar");
const observe_process_1 = require("../utils/observe-process");
const tool_1 = require("./tool");
class Apktool extends tool_1.default {
    constructor(options) {
        super();
        this.options = options;
        this.name = 'apktool';
    }
    decode(inputPath, outputPath) {
        return this.run([
            'decode',
            inputPath,
            '--output',
            outputPath,
            '--frame-path',
            this.options.frameworkPath,
        ], 'decoding');
    }
    encode(inputPath, outputPath, useAapt2) {
        return this.run([
            'build',
            inputPath,
            '--output',
            outputPath,
            '--frame-path',
            this.options.frameworkPath,
            ...(useAapt2 ? ['--use-aapt2'] : []),
        ], `encoding-${useAapt2 ? 'aapt2' : 'aapt'}`);
    }
    run(args, logName) {
        return operators_1.map((line) => line.replace(/I: /g, ''))(observe_process_1.default(execute_jar_1.executeJar(this.path, args), logName));
    }
    get path() {
        return this.options.customPath || this.jarPath;
    }
    get version() {
        if (this.options.customPath)
            return { name: chalk.italic('custom version') };
        const versionNumber = '2.5.0';
        return {
            name: `v${versionNumber}`,
            downloadUrl: 'https://github.com/iBotPeaches/Apktool/releases/download' +
                `/v${versionNumber}/apktool_${versionNumber}.jar`,
        };
    }
}
exports.default = Apktool;
