"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("./fs");
const rxjs_1 = require("rxjs");
const followRedirects = require("follow-redirects");
const { https } = followRedirects;
function downloadFile(url, path) {
    return new rxjs_1.Observable(subscriber => {
        https
            .get(url, response => {
            if (response.statusCode !== 200) {
                const error = new Error(`The URL "${url}" returned status code ${response.statusCode}, expected 200.`);
                // Cancel download with error
                response.destroy(error);
            }
            const fileStream = fs.createWriteStream(path);
            const totalLength = parseInt(response.headers['content-length']);
            let currentLength = 0;
            const reportProgress = () => {
                const percentage = currentLength / totalLength;
                subscriber.next(`${(percentage * 100).toFixed(2)}% done (${formatBytes(currentLength)} / ${formatBytes(totalLength)} MB)`);
            };
            reportProgress();
            response.pipe(fileStream);
            response.on('data', (chunk) => {
                currentLength += chunk.byteLength;
                reportProgress();
            });
            response.on('error', error => subscriber.error(error));
            fileStream.on('close', () => subscriber.complete());
        })
            .on('error', error => subscriber.error(error));
    });
}
exports.default = downloadFile;
function formatBytes(bytes) {
    return (bytes / 1000000).toFixed(2);
}
