"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCachedPath = void 0;
const fs = require("./fs");
const pathUtils = require("path");
const envPaths = require("env-paths");
const observe_async_1 = require("./observe-async");
const download_file_1 = require("./download-file");
const cachePath = envPaths('apk-mitm', { suffix: '' }).cache;
function createToolDownloadTask(tool) {
    return {
        title: `Downloading ${tool.name} ${tool.version.name}`,
        task: (_, task) => {
            if (!tool.version.downloadUrl)
                return task.skip('Using custom version');
            const fileName = `${tool.name}-${tool.version.name}.jar`;
            return downloadCachedFile(task, tool.version.downloadUrl, fileName);
        },
    };
}
exports.default = createToolDownloadTask;
function downloadCachedFile(task, url, fileName) {
    return observe_async_1.default(async (log) => {
        const finalFilePath = getCachedPath(fileName);
        if (await fs.exists(finalFilePath)) {
            task.skip('Version already downloaded!');
            return;
        }
        // Ensure cache directory exists
        await fs.mkdir(cachePath, { recursive: true });
        // Prevent file corruption by using a temporary file name
        const downloadFilePath = finalFilePath + '.dl';
        await download_file_1.default(url, downloadFilePath).forEach(line => {
            // Hide verbose download progress in non-TTY mode
            if (!process.stdout.isTTY)
                return;
            log(line);
        });
        await fs.rename(downloadFilePath, finalFilePath);
    });
}
function getCachedPath(name) {
    return pathUtils.join(cachePath, name);
}
exports.getCachedPath = getCachedPath;
