"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
/**
 * Wraps an async function and produces an `Observable` that reacts to the
 * function resolving (`complete` notification), rejecting (`error`
 * notification), and calling the `next` callback (`next` notification), making
 * it easier to write `async`/`await`-based code that reports its progress
 * through an `Observable` *without* forgetting to handle errors.
 */
function observeAsync(fn) {
    return new rxjs_1.Observable(subscriber => {
        fn(value => subscriber.next(value))
            .then(() => subscriber.complete())
            .catch(error => subscriber.error(error));
    });
}
exports.default = observeAsync;
