"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const rxjs_1 = require("rxjs");
/**
 * Takes in a `Listr` instance, runs it, and reports on its progress through the
 * `Observable` it returns. This can be useful for executing one of the many
 * `Listr`-based functions while redirecting its output somewhere other than
 * standard output.
 *
 * Originally added for [APKLab](https://github.com/Surendrajat/APKLab)'s
 * integration of apk-mitm.
 */
function observeListr(listr) {
    return new rxjs_1.Observable(subscriber => {
        latestSubscriber = subscriber;
        listr.setRenderer(ObservableRenderer);
        listr.run().catch(() => { });
    });
}
exports.default = observeListr;
/**
 * "Handover variable" that allow `observeListr` to pass its `Subscriber` to the
 * `ObservableRenderer` which is instantiated by Listr interally.
 */
let latestSubscriber;
class ObservableRenderer {
    constructor(tasks) {
        this.tasks = tasks;
        this.subscriber = latestSubscriber;
    }
    static get nonTTY() {
        return true;
    }
    render() {
        for (const [index, task] of this.tasks.entries()) {
            task.subscribe(event => {
                var _a;
                if (event.type === 'STATE') {
                    if (task.isPending()) {
                        const progress = `${index + 1}/${this.tasks.length}`;
                        const message = chalk `{dim [${progress}]} ${task.title}`;
                        return this.subscriber.next(message);
                    }
                    else if (task.isSkipped()) {
                        return this.subscriber.next((_a = task.output) !== null && _a !== void 0 ? _a : '');
                    }
                }
                else if (event.type === 'DATA' && !task.hasFailed()) {
                    this.subscriber.next(`${event.data}`);
                }
            });
        }
    }
    end(error) {
        if (error)
            return this.subscriber.error(error);
        this.subscriber.complete();
    }
}
